@@ -1,16 +1,19 @@
-# Copyrights 2005-2014 by [Mark Overmeer].
+# Copyrights 2005-2018 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
-
-use strict;
-use warnings;
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution Geo-Point.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Geo::Shape;
 use vars '$VERSION';
-$VERSION = '0.95';
+$VERSION = '0.97';
 
 
+use strict;
+use warnings;
+
 use Geo::Proj;      # defines wgs84
 use Geo::Point      ();
 use Geo::Line       ();
@@ -27,12 +30,16 @@ use overload '""'     => 'string'
            , fallback => 1;
 
 
-sub new(@) { my $class = shift; (bless {}, $class)->init( {@_} ) }
+sub new(@) {
+    my ($thing, %args) = @_;
+    $args{proj} ||= $thing->proj if ref $thing;
+	(bless {}, ref $thing || $thing)->init(\%args);
+}
 
 sub init($)
 {   my ($self, $args) = @_;
     my $proj = $self->{G_proj}
-             = $args->{proj} || Geo::Proj->defaultProjection->nick;
+      = $args->{proj} || Geo::Proj->defaultProjection->nick;
 
     croak "proj parameter must be a label, not a Geo::Proj object"
         if UNIVERSAL::isa($proj, 'Geo::Proj');
@@ -42,17 +49,11 @@ sub init($)
 
 #---------------------------
 
-
-sub proj()  {shift->{G_proj} }
-
-
-sub proj4()
-{   Geo::Proj->proj4(shift->{G_proj});
-}
+sub proj()  { shift->{G_proj} }
+sub proj4() { Geo::Proj->proj4(shift->{G_proj}) }
 
 #---------------------------
 
-
 sub in($) { croak "ERROR: in() not implemented for a ".ref(shift) }
 
 
@@ -81,7 +82,6 @@ sub projectOn($@)
 
 #---------------------------
 
-
 my $geodist;
 sub distance($;$)
 {   my ($self, $other, $unit) = (shift, shift, shift);
@@ -127,9 +127,7 @@ sub bboxRing(@)
 }
 
 
-sub bbox()
-{   confess "INTERNAL: bbox() not implemented for ".ref(shift);
-}
+sub bbox() { confess "INTERNAL: bbox() not implemented for ".ref(shift) }
 
 
 sub bboxCenter()
@@ -139,14 +137,10 @@ sub bboxCenter()
 }
 
 
-sub area()
-{   confess "INTERNAL: area() not implemented for ".ref(shift);
-}
+sub area() { confess "INTERNAL: area() not implemented for ".ref(shift) }
 
 
-sub perimeter()
-{   confess "INTERNAL: perimeter() not implemented for ".ref(shift);
-}
+sub perimeter() { confess "INTERNAL: perimeter() not implemented for ".ref(shift) }
 
 
 sub deg2dms($$$)
@@ -161,7 +155,6 @@ sub deg2dms($$$)
     }
 
     my $d       = int $degrees;
-
     my $frac    = ($degrees - $d) * 60;
     my $m       = int($frac + 0.00001);
     my $s       = ($frac - $m) * 60;
@@ -204,12 +197,12 @@ sub dms2deg($)
    my $o = 'E';
    $dms =~ s/^\s+//;
 
-   if($dms =~ s/([ewsn])\s*$//i)    { $o = uc($1) }
-   elsif($dms =~ s/^([ewsn])\s*//i) { $o = uc($1) }
+      if($dms =~ s/([ewsn])\s*$//i) { $o = uc $1 }
+   elsif($dms =~ s/^([ewsn])\s*//i) { $o = uc $1 }
 
-   if($dms =~ m/^( [+-]? \d+ (?: \.\d+)? )     [\x{B0}dD]?
-                 \s* (?: ( \d+ (?: \.\d+)? )   [\'mM\x{92}]? )?
-                 \s* (?: ( \d+ (?: \.\d+)? )   [\"sS]? )?
+   if($dms =~ m/^( [+-]? \d+ (?: \.\d+)? )   [\x{B0}dD]?
+               \s* (?: ( \d+ (?: \.\d+)? )   [\'mM\x{92}]? )?
+               \s* (?: ( \d+ (?: \.\d+)? )   [\"sS]? )?
                /xi
      )
    {   my ($d, $m, $s) = ($1, $2||0, $3||0);
