@@ -1,17 +1,20 @@
-# Copyrights 2005-2014 by [Mark Overmeer].
+# Copyrights 2005-2018 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
-
-use strict;
-use warnings;
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution Geo-Point.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Geo::Space;
 use vars '$VERSION';
-$VERSION = '0.95';
+$VERSION = '0.97';
 
 use base 'Geo::Shape';
 
+use strict;
+use warnings;
+
 use Math::Polygon::Calc    qw/polygon_bbox/;
 use List::Util             qw/sum first/;
 
@@ -53,13 +56,13 @@ sub component(@)
 sub nrComponents() { scalar @{shift->{GS_comp}} }
 
 
-sub points()     { grep {$_->isa('Geo::Points')} shift->components }
+sub points()     { grep $_->isa('Geo::Points'), shift->components }
 
 
 sub onlyPoints() { not first {! $_->isa('Geo::Points')} shift->components }
 
 
-sub lines()      { grep {$_->isa('Geo::Line')} shift->components }
+sub lines()      { grep $_->isa('Geo::Line'), shift->components }
 
 
 sub onlyLines()  { not first {! $_->isa('Geo::Line')} shift->components }
@@ -86,15 +89,15 @@ sub in($)
 
 sub bbox()
 {   my $self = shift;
-    my @bboxes = map { [$_->bbox] } $self->components;
-    polygon_bbox(map { ([$_->[0], $_->[1]], [$_->[2], $_->[3]]) } @bboxes);
+    my @bboxes = map [$_->bbox], $self->components;
+    polygon_bbox(map +([$_->[0], $_->[1]], [$_->[2], $_->[3]]), @bboxes);
 }
 
 
-sub area() { sum map { $_->area } shift->components }
+sub area() { sum map $_->area, shift->components }
 
 
-sub perimeter() { sum map { $_->perimeter } shift->components }
+sub perimeter() { sum map $_->perimeter, shift->components }
 
 
 sub toString(;$)
